==> hermes-5.1.0.2.rec2.tar.gz: hermes-5.1.0.2.rec2/config/routes.rb <==
Hermes::Engine.routes.draw do
  namespace :api do
    namespace :dmo do
      generate_logs_routes
      resources :housing_request_shares, only: :create do
        collection do
          get :find_by_housing_request_id
        end
      end
      resources :housing_request_shares, only: :show, controller: '/hermes/api/housing_request_shares' # no authenticated routes
      resources :applicants do
        member do
          get 'eligible_offers'
          post 'switch'

        end
        collection do
          get :find_by_nud
        end
      end

      resources :entity_validations
      resources :entity_reservations
      resources :entities do
        member do
          put 'switch_manual_mode'
          post 'add_points', to: "entities#add_points"
          get 'user_rights'
          get 'housing_requests_count'
        end
        collection do
          get 'admin_search'
        end
        resources :housing_request_entity_form_levels
      end
      resources :housing_request_entity_forms do
        get :actives, on: :collection
        get :show_request, on: :member
      end
      resources :entity_codes, only: [:index, :create, :destroy] do
        post :check_entity_code_validity, on: :collection
      end
      resources :lessor_objective_histories
      resources :housing_applications do
        collection do
          post :attribution
        end
      end
      resources :untensed_areas

      post 'housing_applications/update_status', to: "housing_applications#update_status"

      resources :housing_offers do
        collection do
          get 'with_validated_applications/:id', action: 'with_validated_applications_for'
          get 'with_validated_applications'
          get 'reference_exist'
          post 'search'
        end
        member do
          resources :pictures, only: [:create, :update, :destroy]
          get 'eligible_requests'
          get 'entity_statuses'
          get 'selected_applications'
          post 'selected_applications', to: 'housing_offers#post_selected_applications'
          get "all_applications",  to: 'housing_offers#all_applications'
          get 'history'
          post 'add_housing_channel'
          post 'remove_housing_channel'
        end
      end
      generate_notifications_routes # Helper to generate all notifications routes

      resources :housing_channels
      resources :housing_channel_settings
      resources :housing_offer_expiration_settings
      resources :public_housing_offers
      resources :users, only: [:index, :show, :create, :update] do
        post :switch, on: :member
      end
      delete 'user_rights/all_from_user', to: 'user_rights#delete_all_from_user'
      resources :user_rights, only: [:show, :index, :create, :destroy, :update] do 
        collection do 
          delete 'bulk', to: 'user_rights#delete_bulk'
          post 'bulk', to: 'user_rights#post_bulk'
          post 'search'
        end 
      end 
      resources :operations
      resources :management_areas
      resources :lessor_contacts
      resources :nud_providers
      resources :housing_request_initializers, only: [:show, :index] 

      get 'rex/root_elements', to: 'rex#root_elements'
      get 'rex/:id/subsidiaries', to: 'rex#subsidiaries'
      get 'rex/:id', to: 'rex#show', as: :show


      resources :housing_requests do
        collection do
          get 'clp_details'
          get 'admin_search'
          post 'send_message'
          post 'send_flux_thirty'
          post 'search'
        end
        member do
          get 'zip'
          get 'entity_note'
          get 'internal_note'
          put 'update_internal_note'
          put 'update_entity_note'
          get 'housing_request_folder'
          get 'entity_requests'
          get 'waiting_points'
          get 'spent_points'
          post 'add_points_to_housing_request'
          post 'housing_request_folder/change_confirmed', to: "housing_requests#change_confirmed"
          post 'add_housing_channel'
          post 'validate_housing_channel'
          post 'remove_housing_channel'
          post 'update_from_sne'
          post 'validate_code'
          post 'notify'
          post 'send_flux_thirty_sync'
          get 'xml_sopra_errors'
        end
      end

 
      get 'required_documents/:id/historical_status', to: "required_documents#historical_status"
      get 'required_documents/:id', to: "required_documents#show"
      patch 'required_documents/:id', to: "required_documents#update"
      put 'required_documents/:id', to: "required_documents#update"

      resources :lessors do
        collection do
          get 'admin_search'
        end
        member do
          get 'all_objectives'
          get 'active_objectives'
          put 'switch_manual_mode'
          get 'current_operation_names'
          put :add_user
          put :remove_user
          get :rdsl
        end
      end

      resources :lessor_objectives
      resources :nuds do
        collection do
          get 'pending_for_current_user'
          get 'sne_department_list'
          get 'imhoweb_department_list'
        end
        member do
          post 'send_pin_code_on_mail'
          post 'send_new_pin_code'
          post 'hydrate_housing_request_from_sne'
          post 'authentify_with_pin_code'
        end
      end
      resources :thresholds
      resources :contact_groups
      resources :statuses do
        get :applications_history, on: :collection
      end

      namespace :public_forms do
        get 'captcha'
        post 'confirm'
      end

      resources :reservation_holders
      
      get 'doc', to: "documentation#show_summary", as: 'summary_doc'
      get 'doc/intro', to: "documentation#show_intro", as: 'intro_doc'
      get 'doc/lexicon', to: "documentation#show_lexicon", as: 'lexicon_doc'
      get 'doc/flux', to: "documentation#show_flux", as: 'flux_doc'
      get 'doc/housing_request', to: "documentation#show_housing_request", as: 'housing_request_doc'
      get 'doc/housing_offer', to: "documentation#show_housing_offer", as: 'housing_offer_doc'
      get 'doc/company', to: "documentation#show_company", as: 'company_doc'
      get 'doc/employee', to: "documentation#show_employee", as: 'employee_doc'
      get 'doc/lessor', to: "documentation#show_lessor", as: 'lessor_doc'
      get 'doc/transverse', to: "documentation#show_transverse", as: 'transverse_doc'
      get 'doc/scripts', to: "documentation#show_scripts", as: 'script_doc'

      get 'changelog', to: "documentation#show_changelog"
    end # end of /api/dmo
  end # end of /api

  namespace :admin do # /admin
    resources :thresholds do
    end

    resources :housing_requests, only: %i[index create destroy update], path: :housing_requests do # /admin/housing_requests
    end

    resources :untensed_areas, only: %i[index create destroy update], path: :areas do # /admin/areas
      collection do
        get 'download_csv'
      end
    end
    resources :xml_errors, only: %i[index create destroy update], path: :xml_errors do # /admin/areas
      member do
        post 'replay'
      end
    end
  end # end of /admin



  get '/hermes/gedfile/*path', to: "geds#file", :format => false
end

==> hermes-5.1.0.12.rec2.tar.gz: hermes-5.1.0.12.rec2/config/routes.rb <==
Hermes::Engine.routes.draw do
  namespace :api do
    namespace :dmo do
      generate_logs_routes
      resources :housing_request_shares, only: :create do
        collection do
          get :find_by_housing_request_id
        end
      end
      resources :housing_request_shares, only: :show, controller: '/hermes/api/housing_request_shares' # no authenticated routes
      resources :applicants do
        member do
          get 'eligible_offers'
          post 'switch'

        end
        collection do
          get :find_by_nud
        end
      end

      resources :entity_validations
      resources :entity_reservations
      resources :entities do
        member do
          put 'switch_manual_mode'
          post 'add_points', to: "entities#add_points"
          get 'user_rights'
          get 'housing_requests_count'
        end
        collection do
          get 'admin_search'
        end
        resources :housing_request_entity_form_levels
      end
      resources :housing_request_entity_forms do
        get :actives, on: :collection
        get :show_request, on: :member
      end
      resources :entity_codes, only: [:index, :create, :destroy] do
        post :check_entity_code_validity, on: :collection
      end
      resources :lessor_objective_histories
      resources :housing_applications do
        collection do
          post :attribution
        end
      end
      resources :untensed_areas

      post 'housing_applications/update_status', to: "housing_applications#update_status"

      resources :housing_offers do
        collection do
          get 'with_validated_applications/:id', action: 'with_validated_applications_for'
          get 'with_validated_applications'
          get 'reference_exist'
          post 'search'
        end
        member do
          resources :pictures, only: [:create, :update, :destroy]
          get 'eligible_requests'
          get 'entity_statuses'
          get 'selected_applications'
          post 'selected_applications', to: 'housing_offers#post_selected_applications'
          get "all_applications",  to: 'housing_offers#all_applications'
          get 'history'
          post 'add_housing_channel'
          post 'remove_housing_channel'
        end
      end
      generate_notifications_routes # Helper to generate all notifications routes

      resources :housing_channels
      resources :housing_channel_settings
      resources :housing_offer_expiration_settings
      resources :public_housing_offers
      resources :users, only: [:index, :show, :create, :update] do
        post :switch, on: :member
      end
      delete 'user_rights/all_from_user', to: 'user_rights#delete_all_from_user'
      resources :user_rights, only: [:show, :index, :create, :destroy, :update] do 
        collection do 
          delete 'bulk', to: 'user_rights#delete_bulk'
          post 'bulk', to: 'user_rights#post_bulk'
          post 'search'
        end 
      end 
      resources :operations
      resources :management_areas
      resources :lessor_contacts
      resources :nud_providers
      resources :housing_request_initializers, only: [:show, :index] 

      get 'rex/root_elements', to: 'rex#root_elements'
      get 'rex/:id/subsidiaries', to: 'rex#subsidiaries'
      get 'rex/:id', to: 'rex#show', as: :show


      resources :housing_requests do
        collection do
          get 'clp_details'
          get 'admin_search'
          post 'send_message'
          post 'send_flux_thirty'
          post 'search'
        end
        member do
          get 'zip'
          get 'entity_note'
          get 'internal_note'
          put 'update_internal_note'
          put 'update_entity_note'
          get 'housing_request_folder'
          get 'entity_requests'
          get 'waiting_points'
          get 'spent_points'
          post 'add_points_to_housing_request'
          post 'housing_request_folder/change_confirmed', to: "housing_requests#change_confirmed"
          post 'add_housing_channel'
          post 'validate_housing_channel'
          post 'remove_housing_channel'
          post 'update_from_sne'
          post 'validate_code'
          post 'notify'
          post 'send_flux_thirty_sync'
          get 'xml_sopra_errors'
        end
      end

 
      get 'required_documents/:id/historical_status', to: "required_documents#historical_status"
      get 'required_documents/:id', to: "required_documents#show"
      patch 'required_documents/:id', to: "required_documents#update"
      put 'required_documents/:id', to: "required_documents#update"

      resources :lessors do
        collection do
          get 'admin_search'
        end
        member do
          get 'all_objectives'
          get 'active_objectives'
          put 'switch_manual_mode'
          get 'current_operation_names'
          put :add_user
          put :remove_user
          get :rdsl
        end
      end

      resources :lessor_objectives
      resources :nuds do
        collection do
          get 'pending_for_current_user'
          get 'sne_department_list'
          get 'imhoweb_department_list'
        end
        member do
          post 'send_pin_code_on_mail'
          post 'send_new_pin_code'
          post 'hydrate_housing_request_from_sne'
          post 'authentify_with_pin_code'
        end
      end
      resources :thresholds
      resources :contact_groups
      resources :statuses do
        get :applications_history, on: :collection
      end

      namespace :public_forms do
        get 'captcha'
        post 'confirm'
      end

      resources :reservation_holders
      
      get 'doc', to: "documentation#show_summary", as: 'summary_doc'
      get 'doc/intro', to: "documentation#show_intro", as: 'intro_doc'
      get 'doc/lexicon', to: "documentation#show_lexicon", as: 'lexicon_doc'
      get 'doc/flux', to: "documentation#show_flux", as: 'flux_doc'
      get 'doc/housing_request', to: "documentation#show_housing_request", as: 'housing_request_doc'
      get 'doc/housing_offer', to: "documentation#show_housing_offer", as: 'housing_offer_doc'
      get 'doc/company', to: "documentation#show_company", as: 'company_doc'
      get 'doc/employee', to: "documentation#show_employee", as: 'employee_doc'
      get 'doc/lessor', to: "documentation#show_lessor", as: 'lessor_doc'
      get 'doc/transverse', to: "documentation#show_transverse", as: 'transverse_doc'
      get 'doc/scripts', to: "documentation#show_scripts", as: 'script_doc'

      get 'changelog', to: "documentation#show_changelog"
    end # end of /api/dmo
  end # end of /api

  namespace :admin do # /admin
    resources :thresholds
    resources :nud_providers, only: %i[index new edit create update destroy]
    resources :housing_requests, only: %i[index create destroy update], path: :housing_requests # /admin/housing_requests
    resources :untensed_areas, only: %i[index create destroy update], path: :areas do # /admin/areas
      collection do
        get 'download_csv'
      end
    end
    resources :xml_errors, only: %i[index create destroy update], path: :xml_errors do # /admin/areas
      member do
        post 'replay'
      end
    end
  end # end of /admin

  get '/hermes/gedfile/*path', to: "geds#file", :format => false
end
